
## CATO-CLI - query.catalogs.catalogApplication:
[Click here](https://api.catonetworks.com/documentation/#query-query.catalogs.catalogApplication) for documentation on this operation.

### Usage for query.catalogs.catalogApplication:

```bash
catocli query catalogs catalogApplication -h

catocli query catalogs catalogApplication <json>

catocli query catalogs catalogApplication --json-file query.catalogs.catalogApplication.json

catocli query catalogs catalogApplication '{"applicationRefInput":{"by":"ID","input":"string"}}'

catocli query catalogs catalogApplication '{
    "applicationRefInput": {
        "by": "ID",
        "input": "string"
    }
}'
```

#### Operation Arguments for query.catalogs.catalogApplication ####

`accountId` [ID] - (required) N/A    
`applicationRefInput` [ApplicationRefInput] - (required) N/A    
